CA03-Cl01
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Section |
clickAndWait | link=Añadir section |
type | id_name_es | CA03-Cl01 Section
type | id_slug | ca03-cl01-section
select | id_status | label=Publicado
clickAndWait | _continue |
clickAndWait | link=Ver en el sitio |
verifyTextPresent | Inicio → CA03-Cl01 Section |
verifyTextPresent | CA03-Cl01 Section |
verifyTextPresent | CA03-Cl01 Section |
verifyTextPresent | You can edit in here |
clickAndWait | //div[@id='content']/a/span |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
open | / |
verifyTextNotPresent | CA03-Cl01 Section |
verifyElementNotPresent | link=CA03-Cl01 Section |
open | /admin/ |
clickAndWait | link=Terminar sesión |